Command-line-interface (CLI)
============================

.. automodule:: cruiseplan.cli
   :members:


cruiseplan.cli.main module
--------------------------

.. automodule:: cruiseplan.cli.main
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.cli.pangaea module
-----------------------------

.. automodule:: cruiseplan.cli.pangaea
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.cli.stations module
------------------------------

.. automodule:: cruiseplan.cli.stations
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.cli.enrich module
----------------------------

.. automodule:: cruiseplan.cli.enrich
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.cli.validate module
------------------------------

.. automodule:: cruiseplan.cli.validate
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.cli.schedule module
------------------------------

.. automodule:: cruiseplan.cli.schedule
   :members:
   :undoc-members:
   :show-inheritance:

cruiseplan.cli.utils module
---------------------------

.. automodule:: cruiseplan.cli.utils
   :members:
   :undoc-members:
   :show-inheritance: